@@ -1,9 +1,9 @@
 import re
+import sys
 
-
-SEM_TAKE = intern("take")
-SEM_GIVE = intern("give")
-SEM_KEEP = intern("keep")
+SEM_TAKE = "take"
+SEM_GIVE = "give"
+SEM_KEEP = "keep"
 
 ISL_SEM_TO_SEM = {
     "__isl_take": SEM_TAKE,
@@ -105,7 +105,7 @@ PART_TO_CLASSES = {
         ]
         }
 CLASSES = []
-for cls_list in PART_TO_CLASSES.itervalues():
+for cls_list in PART_TO_CLASSES.values():
     CLASSES.extend(cls_list)
 
 CLASS_MAP = {
@@ -344,7 +344,7 @@ class FunctionData:
     def parse_decl(self, decl):
         decl_match = DECL_RE.match(decl)
         if decl_match is None:
-            print "WARNING: func decl regexp not matched: %s" % decl
+            print("WARNING: func decl regexp not matched: %s" % decl)
             return
 
         return_base_type = decl_match.group(1)
@@ -369,7 +369,7 @@ class FunctionData:
             name = name[len(cls)+1:]
 
         if not found_class:
-            for fake_cls, cls in CLASS_MAP.iteritems():
+            for fake_cls, cls in CLASS_MAP.items():
                 if name.startswith(fake_cls):
                     found_class = True
                     break
@@ -382,7 +382,7 @@ class FunctionData:
         try:
             args = [parse_arg(arg) for arg in args]
         except BadArg:
-            print "SKIP:", cls, name
+            print("SKIP: %s %s" % (cls, name))
             return
 
         if name in PYTHON_RESERVED_WORDS:
@@ -886,8 +886,9 @@ def write_wrappers(expf, wrapf, methods):
         except Retry:
             arg_names, doc_str = write_wrapper(wrapf, meth)
             write_exposer(expf, meth, arg_names, doc_str, static_decls)
-        except SignatureNotSupported, e:
-            print "SKIP (sig not supported: %s): %s" % (e, meth)
+        except SignatureNotSupported:
+            _, e, _ = sys.exc_info()
+            print("SKIP (sig not supported: %s): %s" % (e, meth))
         else:
             #print "WRAPPED:", meth
             pass
@@ -895,7 +896,7 @@ def write_wrappers(expf, wrapf, methods):
     for static_decl in static_decls:
         expf.write(static_decl)
 
-    print "SKIP (%d undocumented methods): %s" % (len(undoc), ", ".join(undoc))
+    print("SKIP (%d undocumented methods): %s" % (len(undoc), ", ".join(undoc)))
 
 
 
@@ -922,7 +923,7 @@ def gen_wrapper(include_dirs):
     fdata.read_header("isl/options.h")
 
 
-    for part, classes in PART_TO_CLASSES.iteritems():
+    for part, classes in PART_TO_CLASSES.items():
         expf = open("src/wrapper/gen-expose-%s.inc" % part, "wt")
         wrapf = open("src/wrapper/gen-wrap-%s.inc" % part, "wt")
 
